#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <string.h>
#include "err.h"

/* Parse - split the command in buf into individual arguments */
void parse (char buf[], char *args[])
{
  int i = 0, j = 0;
  
  while (buf[i] != '\0') {
    /* Strip whitespace. Use nulls, so that the previous argument
       is terminated automatically */
    
    for (; buf[i] == ' ' || buf[i] == '\t'; buf[i++] = '\0');

    /* Save the argument */
    args[j] = buf + i;
    j++;
    
    /* Skip over the argument */
    for (; buf[i] != '\0' && buf[i] != ' ' && buf[i] != '\t'; i++);
  } 

  args[j] = 0;
} /* parse */

/* execute - spawn a child process and execute the program */
void execute(char *args[])
{
  int pid;
  
  /*Get a child process*/
  
  switch(pid = fork()) {
    case -1: /* error */
      syserr("Error in fork\n");

    case 0: /* child */
      execvp(args[0], args);
      syserr("Error in execlp %s\n", args[0]);

    default: /* parent */
      while (wait(0) != pid);  /*empty*/
  }
} /* execute */

int main()
{
  char buf[1024], *args[64];
  
  for (;;) {
    /* Prompt for and read a command */
    printf("Command: ");
    
    if  (fgets(buf, sizeof(buf), stdin) == 0) {
      printf("\n");
      return 0;
    }
    
    if (strlen(buf) == 0) 
      continue;
    buf[strlen(buf) - 1] = '\0';           /* Removing trailing newline ... */
    
    parse(buf, args);
    execute(args);
  } 
} /* main */
